Package: ChIPDBData
Title: ChIP-seq Target Databases for TFEA.ChIP
Version: 1.0.0
Authors@R: c(person(given = "Yosra", family = "Berrouayel", email = "yosraberrouayel@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0002-0768-5933")),
	     person(given = "Luis", family = "del Peso", email = "lpeso@iib.uam.es", role = c("aut"), comment = c(ORCID = "0000-0003-4014-5688")))
Description: Provides curated gene target databases derived from ChIP-seq datasets, formatted as ChIPDB objects for use with TFEA.ChIP.
License: GPL-3
Imports: ExperimentHub
Suggests: knitr, rmarkdown, BiocStyle, AnnotationHub, TFEA.ChIP,
        DESeq2, testthat (>= 3.0.0)
biocViews: ExperimentData, ExperimentHub, Homo_sapiens_Data, ENCODE,
        SequencingData
VignetteEngine: knitr::rmarkdown
VignetteBuilder: knitr
URL: https://github.com/yberda/ChIPDBData
BugReports: https://github.com/yberda/ChIPDBData/issues
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/ChIPDBData
git_branch: RELEASE_3_22
git_last_commit: 5162621
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 15:15:57 UTC; biocbuild
Author: Yosra Berrouayel [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0768-5933>),
  Luis del Peso [aut] (ORCID: <https://orcid.org/0000-0003-4014-5688>)
Maintainer: Yosra Berrouayel <yosraberrouayel@gmail.com>
