#' ChIPDBData: A package for curated ChIP-seq TF target databases
#'
#' The `ChIPDBData` package provides curated ChIP-seq transcription factor
#'  target databases designed for use with TFEA.ChIP
#'
#' @section Package contents:
#' - Functions provided: \code{getChIPDB} (for loading the dataset)
#'
#' @docType package
#' @name ChIPDBData
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end
NULL

